"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "Currency", {
  enumerable: true,
  get: function get() {
    return _Currency["default"];
  }
});
exports["default"] = exports.Currencies = exports.USD = exports.ThaiBaht = void 0;

var _Currency = _interopRequireDefault(require("./Currency"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
 * The main class for Satang
 */
var ThaiBaht = new _Currency["default"]({
  symbol: '฿',
  code: 'THB',
  prettyCode: 'THB',
  fullName: 'Thai Baht',
  locale: 'th-TH'
});
exports.ThaiBaht = ThaiBaht;
var USD = new _Currency["default"]({
  symbol: '$',
  code: 'USD',
  prettyCode: 'USD',
  fullName: 'United States Dollar',
  locale: 'en-US'
});
exports.USD = USD;
var Currencies = {
  THB: ThaiBaht,
  USD: USD
};
exports.Currencies = Currencies;

var Satang = /*#__PURE__*/function () {
  /**
   * constructor for the Satang class
   * @param  {String} baseCurrency  has to be one of the options available in Currencies. Defaults to THB
   * @param  {Number} money         the amount of money this instance of Satang represents in subunits. Money in satang for Thai baht or in cents for Dollar
   */
  function Satang() {
    var baseCurrency = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : ThaiBaht;
    var money = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

    _classCallCheck(this, Satang);

    if (!(baseCurrency instanceof _Currency["default"])) {
      throw new Error("Unrecognized base currency: baseCurrency should be an instance of Currency class. Check the docs for more info");
    }

    if (money === Infinity) {
      throw new Error('Get out');
    }

    if (!Number.isFinite(money) || isNaN(money)) {
      throw new Error('Money is not a number');
    }

    if (money < 0) {
      throw new Error('Minimum money value is 0');
    }

    this.baseCurrency = baseCurrency;
    this.money = money;
  }
  /**
   * Returns supported currencies array.
   * @return {Array} An array of objects. Each Object represents a currency
   */


  _createClass(Satang, [{
    key: "display",

    /**
     * Returns a pretty string that represents the information stored in this Satang class
     * @return {String}
     */
    value: function display() {
      return this.baseCurrency.display(this.money);
    }
    /**
     * Merges the supplied satang to this. Can be chained.
     * @param {Satang} satangToAdd The satang to be added to this
     *
     * @return {Satang} return the modified version of this
     */

  }, {
    key: "add",
    value: function add(satangToAdd) {
      if (!(satangToAdd instanceof Satang)) {
        throw new Error('Only a satang can be added to a satang');
      }

      if (this.baseCurrency.code !== satangToAdd.baseCurrency.code) {
        throw new Error('Satangs should be setup with same base currencies if they are to be added');
      }

      this.money = this.money + satangToAdd.money;
      return this;
    }
  }], [{
    key: "supportedCurrencies",
    value: function supportedCurrencies() {
      return Object.values(Currencies);
    }
  }]);

  return Satang;
}();

var _default = Satang;
exports["default"] = _default;